==> haskell-primitive-0.9.1.0-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive
version:              0.9.1.0
visibility:           public
id:                   primitive-0.9.1.0-GwVG9kES81dKICwS7ZHr7
key:                  primitive-0.9.1.0-GwVG9kES81dKICwS7ZHr7
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           libraries@haskell.org
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/primitive
synopsis:             Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.

category:             Data
abi:                  3c3c197720829fc9c34adbf4eb6ad023
exposed:              True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.Array
    Data.Primitive.ByteArray Data.Primitive.MVar
    Data.Primitive.MachDeps Data.Primitive.MutVar
    Data.Primitive.PrimArray Data.Primitive.PrimVar Data.Primitive.Ptr
    Data.Primitive.SmallArray Data.Primitive.Types

hidden-modules:
    Data.Primitive.Internal.Operations Data.Primitive.Internal.Read

import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive
hs-libraries:         HSprimitive-0.9.1.0-GwVG9kES81dKICwS7ZHr7
include-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0/include
depends:
    base-4.17.2.1 deepseq-1.4.8.0 template-haskell-2.19.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html:         /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-0.9.1.0-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive
version:              0.9.1.0
visibility:           public
id:                   primitive-0.9.1.0-fS4UOWa1Rx1R8aTIzuqbm
key:                  primitive-0.9.1.0-fS4UOWa1Rx1R8aTIzuqbm
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           libraries@haskell.org
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/primitive
synopsis:             Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.

category:             Data
abi:                  1c287bb314ba8e0cda34facbb00de7e2
exposed:              True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.Array
    Data.Primitive.ByteArray Data.Primitive.MVar
    Data.Primitive.MachDeps Data.Primitive.MutVar
    Data.Primitive.PrimArray Data.Primitive.PrimVar Data.Primitive.Ptr
    Data.Primitive.SmallArray Data.Primitive.Types

hidden-modules:
    Data.Primitive.Internal.Operations Data.Primitive.Internal.Read

import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive
hs-libraries:         HSprimitive-0.9.1.0-fS4UOWa1Rx1R8aTIzuqbm
include-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-0.9.1.0/include
depends:
    base-4.17.2.1 deepseq-1.4.8.0 template-haskell-2.19.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html:         /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
